# Main loop for generating logistic models from data
#
# Expects a data.frame named toxData, which should contain at least
# the following columns: Age, Treatment, Temp, Alive, Dead
#
# Generate a list of list of glm named model_grid, as well as
# auxillary vectors named ages and treatments

#--------------------------------------------------------------------
# An example of how to start the codes 
# load common libraries
#		 library(MASS)
# Set the global alpha level to generate the 95% confidence interval
#		 alpha = 0.05
# Set the temperature range to use for prediction
#		 Temp_seq <- seq(23, 38, 0.5)
# Set the working directory
#		 setwd('working_director')  
# Read the csv file that contain the data, must include at least
# the following columns: Age, Treatment, Temp, Alive, Dead 
#		 toxData <- read.csv('example.csv') 	% Use read.csv to load the data file into the data frame. 
# Use the model prediction loop to generate models 
#		 source("model_loop.r")
# Use the does_p_loop to generate a list of LT50s
#		 source("dose_p_loop.r") 
#------------------------------------------------------------------------


model_grid <- list()
ages <- unique(toxData$Age);
treatments <- unique(toxData$Treatment);

for (i in ages){
    model_list <- list();
    for (val in treatments){
        batch <- toxData[toxData$Treatment==val & toxData$Age==i,];
        Alive.Dead <- cbind(batch$Alive, batch$Dead);
        Temp <- batch$Temp;
        model <- glm(Alive.Dead ~ log10(Temp), binomial);
        attr(model, "Age") <- i
        attr(model, "Treatment") <- val
        model_list <- append(model_list, list(model))
    }
    names(model_list) <- treatments
    model_grid <- append(model_grid, list(model_list))
}
names(model_grid) <- ages

# clean-up
rm(model, model_list, i, val, batch, Alive.Dead, Temp)